import csv
from time import time

import requests
from django.core.management import BaseCommand
from django.db import connection, transaction
from tqdm import tqdm

from trainvel.core.models import Station


class Command(BaseCommand):
    def handle(self, *args, **options):
        def convert_value(value: str) -> str:
            return True if value == 't' else False if value == 'f' else (value or None)

        stations = []

        STATIONS_URL = "https://raw.githubusercontent.com/trainline-eu/stations/master/stations.csv"
        with requests.get(STATIONS_URL, stream=True) as resp:
            for row in csv.DictReader(tqdm(resp.iter_lines(decode_unicode=True)), delimiter=';'):
                row: dict
                values = {k.replace(':', '_').replace('normalised_code', 'normalized_code_trainline')
                          .replace('same_as', 'same_as_id'): convert_value(v)
                          for k, v in row.items()}
                stations.append(values)

        Station.objects.all().delete()
        print("Deleted all stations.")
        with connection.cursor() as cursor:
            cursor.execute("BEGIN;")
            keys = ", ".join(stations[0].keys())
            cursor.executemany(
                f"INSERT INTO core_station ({keys}) VALUES ({', '.join(['%s'] * len(values))});",
                [list(station.values()) for station in stations],
            )
            cursor.execute("COMMIT;")
