from trainvel.gtfs.models import GTFSFeed


def keep_gtfs_feed_modification_date(instance: GTFSFeed, raw: bool = True, **_kwargs):
    """
    Keep the last_modified and etag fields from the existing GTFSFeed instance when saving a new one.
    """
    if raw and GTFSFeed.objects.filter(pk=instance.pk).exists():
        # If a GTFSFeed instance is being saved from a raw query,
        # we want to keep the last_modified and etag fields from the existing instance.
        # This is useful when loading initial data from a fixture, for example.
        old_instance = GTFSFeed.objects.get(pk=instance.pk)
        instance.last_modified = old_instance.last_modified
        instance.etag = old_instance.etag
